@@ -19,6 +19,9 @@ export const QueryLibraryInteractions: Record<string, (properties?: QueryLibrary
     queryLibraryInteraction('closed_without_saving_new_query');
   },
   // Outside Interactions
+  savedQueriesDropdownOpened: (properties?: QueryLibraryEventsPropertyMap) => {
+    queryLibraryInteraction('saved_queries_dropdown_opened', properties);
+  },
   addQueryFromLibraryClicked: (properties?: QueryLibraryEventsPropertyMap) => {
     queryLibraryInteraction('add_query_from_library_clicked', properties);
   },
@@ -75,6 +78,9 @@ export const QueryLibraryInteractions: Record<string, (properties?: QueryLibrary
   lockQueryClicked: (properties?: QueryLibraryEventsPropertyMap) => {
     queryLibraryInteraction('lock_query_clicked', properties);
   },
+  openInDrilldownClicked: (properties?: QueryLibraryEventsPropertyMap) => {
+    queryLibraryInteraction('open_in_drilldown_clicked', properties);
+  },
   // Editing
   editQueryClicked: (properties?: QueryLibraryEventsPropertyMap) => {
     queryLibraryInteraction('edit_query_clicked', properties);
