@@ -16,6 +16,7 @@ import {
   LogSortOrderChangeEvent,
 } from '@grafana/data';
 import { getAppEvents } from '@grafana/runtime';
+// eslint-disable-next-line no-restricted-imports
 import * as grafanaUI from '@grafana/ui';
 import * as styles from 'app/features/logs/components/getLogRowStyles';
 import { LogRowContextModal } from 'app/features/logs/components/log-context/LogRowContextModal';
@@ -43,6 +44,7 @@ jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
   getAppEvents: jest.fn(),
   getDataSourceSrv: () => getDataSourceSrvMock(),
+  usePluginLinks: jest.fn().mockReturnValue({ links: [] }),
 }));
 
 const hasLogsContextSupport = jest.fn().mockImplementation((ds) => {
@@ -56,6 +58,13 @@ jest.mock('@grafana/data', () => ({
   hasLogsContextSupport: (ds: MockDataSourceApi) => hasLogsContextSupport(ds),
 }));
 
+jest.mock('@grafana/assistant', () => {
+  return {
+    ...jest.requireActual('@grafana/assistant'),
+    useAssistant: jest.fn().mockReturnValue({ isAvailable: true }),
+  };
+});
+
 const defaultProps = {
   data: {
     error: undefined,
@@ -145,10 +154,10 @@ beforeAll(() => {
   });
 });
 
-describe('LogsPanel', () => {
+describe.each([false, true])('LogsPanel with controls = %s', (showControls: boolean) => {
   it('publishes an event with the current sort order', async () => {
     publishMock.mockClear();
-    setup();
+    setup({}, showControls);
 
     await screen.findByText('logline text');
 
@@ -199,36 +208,52 @@ describe('LogsPanel', () => {
     ];
 
     it('shows common labels when showCommonLabels is set to true', async () => {
-      setup({
-        data: { ...defaultProps.data, series: seriesWithCommonLabels },
-        options: { ...defaultProps.options, showCommonLabels: true },
-      });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true },
+        },
+        showControls
+      );
 
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
       expect(await screen.findByText(/common_app/i)).toBeInTheDocument();
       expect(await screen.findByText(/common_job/i)).toBeInTheDocument();
     });
     it('shows common labels on top when descending sort order', async () => {
-      const { container } = setup({
-        data: { ...defaultProps.data, series: seriesWithCommonLabels },
-        options: { ...defaultProps.options, showCommonLabels: true, sortOrder: LogsSortOrder.Descending },
-      });
+      const { container } = setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true, sortOrder: LogsSortOrder.Descending },
+        },
+        showControls
+      );
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
       expect(container.firstChild?.childNodes[0].textContent).toMatch(/^Common labels:app=common_appjob=common_job/);
     });
     it('shows common labels on bottom when ascending sort order', async () => {
-      const { container } = setup({
-        data: { ...defaultProps.data, series: seriesWithCommonLabels },
-        options: { ...defaultProps.options, showCommonLabels: true, sortOrder: LogsSortOrder.Ascending },
-      });
+      const { container } = setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true, sortOrder: LogsSortOrder.Ascending },
+        },
+        showControls
+      );
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
-      expect(container.firstChild?.childNodes[0].textContent).toMatch(/Common labels:app=common_appjob=common_job$/);
+      if (!showControls) {
+        expect(container.firstChild?.childNodes[0].textContent).toMatch(/Common labels:app=common_appjob=common_job$/);
+      } else {
+        expect(container.childNodes[0].textContent).toMatch(/Common labels:app=common_appjob=common_job$/);
+      }
     });
     it('does not show common labels when showCommonLabels is set to false', async () => {
-      setup({
-        data: { ...defaultProps.data, series: seriesWithCommonLabels },
-        options: { ...defaultProps.options, showCommonLabels: false },
-      });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: false },
+        },
+        showControls
+      );
 
       await waitFor(async () => {
         expect(screen.queryByText(/common labels:/i)).toBeNull();
@@ -261,19 +286,25 @@ describe('LogsPanel', () => {
       }),
     ];
     it('shows (no common labels) when showCommonLabels is set to true', async () => {
-      setup({
-        data: { ...defaultProps.data, series: seriesWithoutCommonLabels },
-        options: { ...defaultProps.options, showCommonLabels: true },
-      });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithoutCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true },
+        },
+        showControls
+      );
 
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
       expect(await screen.findByText(/(no common labels)/i)).toBeInTheDocument();
     });
     it('does not show common labels when showCommonLabels is set to false', async () => {
-      setup({
-        data: { ...defaultProps.data, series: seriesWithoutCommonLabels },
-        options: { ...defaultProps.options, showCommonLabels: false },
-      });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithoutCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: false },
+        },
+        showControls
+      );
       await waitFor(async () => {
         expect(screen.queryByText(/common labels:/i)).toBeNull();
         expect(screen.queryByText(/(no common labels)/i)).toBeNull();
@@ -322,17 +353,20 @@ describe('LogsPanel', () => {
     });
 
     it('should not show the toggle if the datasource does not support show context', async () => {
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
-          request: {
-            ...defaultProps.data.request,
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'no-show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'no-show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
 
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
@@ -341,17 +375,20 @@ describe('LogsPanel', () => {
     });
 
     it('should show the toggle if the datasource does support show context', async () => {
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
-          request: {
-            ...defaultProps.data.request,
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
 
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
@@ -360,17 +397,20 @@ describe('LogsPanel', () => {
     });
 
     it('should not show the toggle if the datasource does support show context but the app is not Dashboard', async () => {
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
-          request: {
-            ...defaultProps.data.request,
-            app: CoreApp.CloudAlerting,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.CloudAlerting,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
 
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
@@ -379,17 +419,20 @@ describe('LogsPanel', () => {
     });
 
     it('should render the mocked `LogRowContextModal` after click', async () => {
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
-          request: {
-            ...defaultProps.data.request,
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
         await userEvent.click(screen.getByLabelText(/show context/i));
@@ -398,17 +441,20 @@ describe('LogsPanel', () => {
     });
 
     it('should call `getLogRowContext` if the user clicks the show context toggle', async () => {
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
-          request: {
-            ...defaultProps.data.request,
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
         await userEvent.click(screen.getByLabelText(/show context/i));
@@ -427,17 +473,20 @@ describe('LogsPanel', () => {
         <grafanaUI.IconButton name="rss" tooltip="Addon after" aria-label="Addon after" key={1} />,
       ];
 
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            logRowMenuIconsBefore,
+            logRowMenuIconsAfter,
+          },
         },
-        options: {
-          ...defaultProps.options,
-          logRowMenuIconsBefore,
-          logRowMenuIconsAfter,
-        },
-      });
+        showControls
+      );
 
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
@@ -488,12 +537,15 @@ describe('LogsPanel', () => {
     });
 
     it('does not rerender without changes', async () => {
-      const { rerender, props } = setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
         },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -504,12 +556,15 @@ describe('LogsPanel', () => {
     });
 
     it('rerenders when prop changes', async () => {
-      const { rerender, props } = setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
         },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -520,12 +575,15 @@ describe('LogsPanel', () => {
     });
 
     it('does not re-render when data is loading', async () => {
-      const { rerender, props } = setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
         },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -571,26 +629,29 @@ describe('LogsPanel', () => {
       const filterForMock = jest.fn();
       const filterOutMock = jest.fn();
       const isFilterLabelActiveMock = jest.fn();
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            onClickFilterLabel: filterForMock,
+            onClickFilterOutLabel: filterOutMock,
+            isFilterLabelActive: isFilterLabelActiveMock,
+          },
         },
-        options: {
-          ...defaultProps.options,
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          onClickFilterLabel: filterForMock,
-          onClickFilterOutLabel: filterOutMock,
-          isFilterLabelActive: isFilterLabelActiveMock,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -610,16 +671,19 @@ describe('LogsPanel', () => {
           eventBus: new EventBusSrv(),
         });
 
-        setup({
-          data: {
-            ...defaultProps.data,
-            series,
+        setup(
+          {
+            data: {
+              ...defaultProps.data,
+              series,
+            },
+            options: {
+              ...defaultProps.options,
+              enableLogDetails: true,
+            },
           },
-          options: {
-            ...defaultProps.options,
-            enableLogDetails: true,
-          },
-        });
+          showControls
+        );
 
         expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -635,16 +699,19 @@ describe('LogsPanel', () => {
           onAddAdHocFilter: jest.fn(),
         });
 
-        setup({
-          data: {
-            ...defaultProps.data,
-            series,
+        setup(
+          {
+            data: {
+              ...defaultProps.data,
+              series,
+            },
+            options: {
+              ...defaultProps.options,
+              enableLogDetails: true,
+            },
           },
-          options: {
-            ...defaultProps.options,
-            enableLogDetails: true,
-          },
-        });
+          showControls
+        );
 
         expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -690,26 +757,29 @@ describe('LogsPanel', () => {
     ];
 
     it('displays the provided fields instead of the log line', async () => {
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            displayedFields: ['app'],
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
         },
-        options: {
-          ...defaultProps.options,
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          displayedFields: ['app'],
-          onClickHideField: undefined,
-          onClickShowField: undefined,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
       expect(screen.queryByText('logline text')).not.toBeInTheDocument();
@@ -724,25 +794,28 @@ describe('LogsPanel', () => {
     });
 
     it('updates the provided fields instead of the log line', async () => {
-      const { rerender, props } = setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
         },
-        options: {
-          ...defaultProps.options,
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          onClickHideField: undefined,
-          onClickShowField: undefined,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
       expect(screen.getByText('logline text')).toBeInTheDocument();
@@ -753,26 +826,29 @@ describe('LogsPanel', () => {
     });
 
     it('enables the behavior with a default implementation', async () => {
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            displayedFields: [],
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
         },
-        options: {
-          ...defaultProps.options,
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          displayedFields: [],
-          onClickHideField: undefined,
-          onClickShowField: undefined,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -789,25 +865,28 @@ describe('LogsPanel', () => {
     it('overrides the default implementation when the callbacks are provided', async () => {
       const onClickShowFieldMock = jest.fn();
 
-      setup({
-        data: {
-          ...defaultProps.data,
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            onClickHideField: jest.fn(),
+            onClickShowField: onClickShowFieldMock,
+          },
         },
-        options: {
-          ...defaultProps.options,
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          onClickHideField: jest.fn(),
-          onClickShowField: onClickShowFieldMock,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -816,17 +895,107 @@ describe('LogsPanel', () => {
 
       expect(onClickShowFieldMock).toHaveBeenCalledTimes(1);
     });
+
+    it('calls onOptionsChange with updated displayedFields when showing a field', async () => {
+      const onOptionsChangeMock = jest.fn();
+
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            displayedFields: [],
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
+          onOptionsChange: onOptionsChangeMock,
+        },
+        showControls
+      );
+
+      expect(await screen.findByRole('row')).toBeInTheDocument();
+      expect(screen.getByText('logline text')).toBeInTheDocument();
+
+      // Click to open log details
+      await userEvent.click(screen.getByText('logline text'));
+      // Click to show the 'app' field
+      await userEvent.click(screen.getByLabelText('Show this field instead of the message'));
+
+      // Verify onOptionsChange was called with the field shown
+      expect(onOptionsChangeMock).toHaveBeenCalledWith(
+        expect.objectContaining({
+          displayedFields: ['app'],
+        })
+      );
+    });
+
+    it('calls onOptionsChange with updated displayedFields when hiding a field', async () => {
+      const onOptionsChangeMock = jest.fn();
+
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            displayedFields: ['app'],
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
+          onOptionsChange: onOptionsChangeMock,
+        },
+        showControls
+      );
+
+      expect(await screen.findByRole('row')).toBeInTheDocument();
+      expect(screen.getByText('app=common_app')).toBeInTheDocument();
+
+      // Click to open log details
+      await userEvent.click(screen.getByText('app=common_app'));
+      // Click to hide the 'app' field
+      await userEvent.click(screen.getByLabelText('Hide this field'));
+
+      // Verify onOptionsChange was called with the field hidden
+      expect(onOptionsChangeMock).toHaveBeenCalledWith(
+        expect.objectContaining({
+          displayedFields: [],
+        })
+      );
+    });
   });
 });
 
-const setup = (propsOverrides?: Partial<LogsPanelProps>) => {
+const setup = (propsOverrides?: Partial<LogsPanelProps>, showControls = false) => {
   const props: LogsPanelProps = {
     ...defaultProps,
+    ...propsOverrides,
     data: {
       ...(propsOverrides?.data || defaultProps.data),
     },
     options: {
       ...(propsOverrides?.options || defaultProps.options),
+      showControls,
     },
   };
 
